# Installation

## Stable release

To install intelligen, run this command in your terminal:

```
pip install intelligen
```

This is the preferred method to install intelligen, as it will always install the most recent stable release.

If you don't have [pip](https://pip.pypa.io) installed, this [Python installation guide](http://docs.python-guide.org/en/latest/starting/installation/) can guide you through the process.

## From sources

The sources for intelligen can be downloaded from the Github repo.

You can clone the public repository:

```
git clone git://github.com/Bouchet07/intelligen
```
